rule win_emotet_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.emotet."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.emotet"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 3c41 7c04 3c5a 7e03 c60158 }
            // n = 5, score = 2900
            //   3c41                 | cmp                 al, 0x41
            //   7c04                 | jl                  6
            //   3c5a                 | cmp                 al, 0x5a
            //   7e03                 | jle                 5
            //   c60158               | mov                 byte ptr [ecx], 0x58

        $sequence_1 = { 7e13 3c61 7c04 3c7a 7e0b 3c41 7c04 }
            // n = 7, score = 2900
            //   7e13                 | jle                 0x15
            //   3c61                 | cmp                 al, 0x61
            //   7c04                 | jl                  6
            //   3c7a                 | cmp                 al, 0x7a
            //   7e0b                 | jle                 0xd
            //   3c41                 | cmp                 al, 0x41
            //   7c04                 | jl                  6

        $sequence_2 = { 3c30 7c04 3c39 7e13 3c61 }
            // n = 5, score = 2900
            //   3c30                 | cmp                 al, 0x30
            //   7c04                 | jl                  6
            //   3c39                 | cmp                 al, 0x39
            //   7e13                 | jle                 0x15
            //   3c61                 | cmp                 al, 0x61

        $sequence_3 = { c60158 41 803900 75dd }
            // n = 4, score = 2400
            //   c60158               | mov                 byte ptr [ecx], 0x58
            //   41                   | inc                 ecx
            //   803900               | cmp                 byte ptr [ecx], 0
            //   75dd                 | jne                 0xffffffdf

        $sequence_4 = { 33c0 3903 5f 5e 0f95c0 5b 8be5 }
            // n = 7, score = 2400
            //   33c0                 | xor                 eax, eax
            //   3903                 | cmp                 dword ptr [ebx], eax
            //   5f                   | pop                 edi
            //   5e                   | pop                 esi
            //   0f95c0               | setne               al
            //   5b                   | pop                 ebx
            //   8be5                 | mov                 esp, ebp

        $sequence_5 = { 83c020 eb03 0fb7c0 69d23f000100 }
            // n = 4, score = 2300
            //   83c020               | add                 eax, 0x20
            //   eb03                 | jmp                 5
            //   0fb7c0               | movzx               eax, ax
            //   69d23f000100         | imul                edx, edx, 0x1003f

        $sequence_6 = { c1e808 8d5204 c1e910 8842fd 884afe }
            // n = 5, score = 2100
            //   c1e808               | cmp                 al, 0x41
            //   8d5204               | jl                  0xc
            //   c1e910               | cmp                 al, 0x5a
            //   8842fd               | cmp                 al, 0x7a
            //   884afe               | jle                 0xd

        $sequence_7 = { 880a 8bc1 c1e808 8d5204 }
            // n = 4, score = 2100
            //   880a                 | jle                 0x17
            //   8bc1                 | cmp                 al, 0x39
            //   c1e808               | jle                 0x15
            //   8d5204               | cmp                 al, 0x61

        $sequence_8 = { 8d5801 f6c30f 7406 83e3f0 }
            // n = 4, score = 2000
            //   8d5801               | lea                 ebx, [eax + 1]
            //   f6c30f               | test                bl, 0xf
            //   7406                 | je                  8
            //   83e3f0               | and                 ebx, 0xfffffff0

        $sequence_9 = { 8b4604 8b16 8945fc 8d45f8 }
            // n = 4, score = 1900
            //   8b4604               | mov                 eax, dword ptr [esi + 4]
            //   8b16                 | mov                 edx, dword ptr [esi]
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   8d45f8               | lea                 eax, [ebp - 8]

        $sequence_10 = { 83c410 8b45fc 0106 294604 }
            // n = 4, score = 1900
            //   83c410               | push                esi
            //   8b45fc               | push                esi
            //   0106                 | push                eax
            //   294604               | push                esi

        $sequence_11 = { 03878c000000 50 ff15???????? 017758 }
            // n = 4, score = 1900
            //   03878c000000         | cmp                 dword ptr [ebx], eax
            //   50                   | pop                 edi
            //   ff15????????         |                     
            //   017758               | pop                 esi

        $sequence_12 = { 8bfa 8bf1 ff15???????? 8b17 83c40c }
            // n = 5, score = 1900
            //   8bfa                 | push                esi
            //   8bf1                 | push                0xf0000040
            //   ff15????????         |                     
            //   8b17                 | push                0x18
            //   83c40c               | xor                 esi, esi

        $sequence_13 = { 8945fc 8d45f8 6a04 50 ff760c }
            // n = 5, score = 1900
            //   8945fc               | push                dword ptr [ebp - 4]
            //   8d45f8               | push                0x400
            //   6a04                 | push                0
            //   50                   | push                0
            //   ff760c               | sub                 esp, 8

        $sequence_14 = { 8b17 83c40c 8b4d0c 8bc2 0bc1 83f8ff }
            // n = 6, score = 1900
            //   8b17                 | movzx               eax, ax
            //   83c40c               | add                 eax, 0x20
            //   8b4d0c               | jmp                 0xb
            //   8bc2                 | movzx               eax, ax
            //   0bc1                 | imul                edx, edx, 0x1003f
            //   83f8ff               | add                 eax, 0x20

        $sequence_15 = { c745fc04000000 50 8d45f8 81ca00000020 50 52 51 }
            // n = 7, score = 1800
            //   c745fc04000000       | cmp                 al, 0x39
            //   50                   | jle                 0x15
            //   8d45f8               | cmp                 al, 0x61
            //   81ca00000020         | jl                  0xa
            //   50                   | cmp                 al, 0x7a
            //   52                   | jle                 0x15
            //   51                   | cmp                 al, 0x41

        $sequence_16 = { 66c1e808 4d8d4004 418840fd 418848fe }
            // n = 4, score = 1700
            //   66c1e808             | mov                 dword ptr [eax + 0x10], edx
            //   4d8d4004             | dec                 esp
            //   418840fd             | mov                 dword ptr [eax + 0x18], eax
            //   418848fe             | dec                 esp

        $sequence_17 = { 418848fe 66c1e908 418848ff 4d3bd9 72cf }
            // n = 5, score = 1700
            //   418848fe             | inc                 ecx
            //   66c1e908             | mov                 byte ptr [eax - 2], cl
            //   418848ff             | shr                 cx, 8
            //   4d3bd9               | inc                 ecx
            //   72cf                 | mov                 byte ptr [eax - 1], cl

        $sequence_18 = { 2bca d1e9 03ca c1e906 894c2430 }
            // n = 5, score = 1700
            //   2bca                 | lea                 eax, [eax + 4]
            //   d1e9                 | inc                 ecx
            //   03ca                 | mov                 byte ptr [eax - 3], al
            //   c1e906               | inc                 ecx
            //   894c2430             | mov                 byte ptr [eax - 2], cl

        $sequence_19 = { 418bd0 d3e2 418bcb d3e0 }
            // n = 4, score = 1700
            //   418bd0               | cmp                 ebx, ecx
            //   d3e2                 | jb                  0xffffffe8
            //   418bcb               | dec                 ebp
            //   d3e0                 | lea                 eax, [eax + 4]

        $sequence_20 = { 488bd3 488bcf 488b5c2460 4883c450 }
            // n = 4, score = 1700
            //   488bd3               | mov                 dword ptr [esp + 0x30], ecx
            //   488bcf               | inc                 ecx
            //   488b5c2460           | mov                 byte ptr [eax - 2], cl
            //   4883c450             | shr                 cx, 8

        $sequence_21 = { d3e7 83f841 7208 83f85a }
            // n = 4, score = 1700
            //   d3e7                 | jle                 9
            //   83f841               | mov                 byte ptr [ecx], 0x58
            //   7208                 | jl                  6
            //   83f85a               | cmp                 al, 0x39

        $sequence_22 = { 418808 0fb7c1 c1e910 66c1e808 }
            // n = 4, score = 1700
            //   418808               | ret                 
            //   0fb7c1               | dec                 eax
            //   c1e910               | mov                 dword ptr [eax + 8], ecx
            //   66c1e808             | dec                 eax

        $sequence_23 = { 49895b08 49896b10 49897318 49897b20 4156 4883ec70 }
            // n = 6, score = 1700
            //   49895b08             | inc                 ecx
            //   49896b10             | mov                 byte ptr [eax - 1], cl
            //   49897318             | sub                 ecx, edx
            //   49897b20             | shr                 ecx, 1
            //   4156                 | add                 ecx, edx
            //   4883ec70             | shr                 ecx, 6

        $sequence_24 = { 48895010 4c894018 4c894820 c3 }
            // n = 4, score = 1700
            //   48895010             | dec                 ebp
            //   4c894018             | cmp                 ebx, ecx
            //   4c894820             | jb                  0xffffffd4
            //   c3                   | dec                 eax

        $sequence_25 = { c1e807 46 83f87f 77f7 }
            // n = 4, score = 1600
            //   c1e807               | dec                 eax
            //   46                   | mov                 dword ptr [eax + 0x10], edx
            //   83f87f               | dec                 esp
            //   77f7                 | mov                 dword ptr [eax + 0x18], eax

        $sequence_26 = { 84c0 75f2 eb03 c60100 }
            // n = 4, score = 1500
            //   84c0                 | mov                 dword ptr [eax + 8], ecx
            //   75f2                 | dec                 eax
            //   eb03                 | mov                 dword ptr [eax + 0x10], edx
            //   c60100               | dec                 esp

        $sequence_27 = { f7e1 b84fecc44e 2bca d1e9 }
            // n = 4, score = 1500
            //   f7e1                 | cmp                 al, 0x39
            //   b84fecc44e           | jle                 0x15
            //   2bca                 | cmp                 al, 0x61
            //   d1e9                 | jl                  0xa

        $sequence_28 = { 8bd3 8b0f e8???????? 85c0 }
            // n = 4, score = 1400
            //   8bd3                 | cmp                 al, 0x39
            //   8b0f                 | jle                 0x17
            //   e8????????           |                     
            //   85c0                 | cmp                 al, 0x61

        $sequence_29 = { 7423 8a01 3c30 7c04 }
            // n = 4, score = 1300
            //   7423                 | jl                  0xe
            //   8a01                 | cmp                 al, 0x41
            //   3c30                 | jl                  6
            //   7c04                 | cmp                 al, 0x5a

        $sequence_30 = { 83c104 894e04 8b00 85c0 }
            // n = 4, score = 1200
            //   83c104               | jle                 7
            //   894e04               | mov                 byte ptr [ecx], 0x58
            //   8b00                 | cmp                 al, 0x7a
            //   85c0                 | jle                 0xd

        $sequence_31 = { 7907 83c107 3bf7 72e8 }
            // n = 4, score = 1200
            //   7907                 | shr                 cx, 8
            //   83c107               | inc                 ecx
            //   3bf7                 | mov                 byte ptr [eax - 1], cl
            //   72e8                 | dec                 ebp

        $sequence_32 = { 56 57 6a1e 8d45e0 }
            // n = 4, score = 1100
            //   56                   | sub                 dword ptr [esi + 4], eax
            //   57                   | mov                 esi, ecx
            //   6a1e                 | mov                 edx, dword ptr [edi]
            //   8d45e0               | add                 esp, 0xc

        $sequence_33 = { 52 52 52 52 68???????? 52 }
            // n = 6, score = 1100
            //   52                   | cmp                 ebx, ecx
            //   52                   | jb                  0xffffffd4
            //   52                   | dec                 ebp
            //   52                   | lea                 eax, [eax + 4]
            //   68????????           |                     
            //   52                   | inc                 ecx

        $sequence_34 = { 83ec48 53 56 57 6a44 }
            // n = 5, score = 1100
            //   83ec48               | cmp                 eax, 0x7f
            //   53                   | jbe                 0xe
            //   56                   | shr                 eax, 7
            //   57                   | inc                 ecx
            //   6a44                 | cmp                 eax, 0x7f

        $sequence_35 = { 83f87f 760d 8d642400 c1e807 }
            // n = 4, score = 1000
            //   83f87f               | shr                 ax, 8
            //   760d                 | dec                 ebp
            //   8d642400             | lea                 eax, [eax + 4]
            //   c1e807               | inc                 ecx

        $sequence_36 = { 83f87f 7609 c1e807 41 83f87f 77f7 }
            // n = 6, score = 900
            //   83f87f               | inc                 ecx
            //   7609                 | mov                 edx, eax
            //   c1e807               | shl                 edx, cl
            //   41                   | inc                 ecx
            //   83f87f               | mov                 ecx, ebx
            //   77f7                 | shl                 eax, cl

        $sequence_37 = { 6a00 6aff 50 51 ff15???????? }
            // n = 5, score = 800
            //   6a00                 | mov                 byte ptr [eax], cl
            //   6aff                 | movzx               eax, cx
            //   50                   | shr                 ecx, 0x10
            //   51                   | shr                 ax, 8
            //   ff15????????         |                     

        $sequence_38 = { 50 6a00 6a01 6a00 ff15???????? a3???????? }
            // n = 6, score = 800
            //   50                   | movzx               eax, cx
            //   6a00                 | shr                 ecx, 0x10
            //   6a01                 | shr                 ax, 8
            //   6a00                 | inc                 ecx
            //   ff15????????         |                     
            //   a3????????           |                     

        $sequence_39 = { 6a00 ff75fc 6800040000 6a00 6a00 6a00 }
            // n = 6, score = 600
            //   6a00                 | mov                 dword ptr [esi + 0x20], ecx
            //   ff75fc               | add                 esp, 0x18
            //   6800040000           | pop                 esi
            //   6a00                 | ret                 
            //   6a00                 | mov                 ebx, ecx
            //   6a00                 | add                 ebx, 0x10

        $sequence_40 = { 50 56 6800800000 6a6a }
            // n = 4, score = 600
            //   50                   | shr                 eax, 7
            //   56                   | inc                 ecx
            //   6800800000           | cmp                 eax, 0x7f
            //   6a6a                 | mov                 ecx, 1

        $sequence_41 = { 53 56 8bf1 bb00c34c84 }
            // n = 4, score = 600
            //   53                   | ja                  5
            //   56                   | jbe                 0xb
            //   8bf1                 | shr                 eax, 7
            //   bb00c34c84           | inc                 ecx

        $sequence_42 = { 56 68400000f0 6a18 33f6 56 56 }
            // n = 6, score = 600
            //   56                   | add                 ebx, 0x3c
            //   68400000f0           | mov                 dword ptr [edx + 4], esi
            //   6a18                 | mov                 dword ptr [edx], esi
            //   33f6                 | mov                 dword ptr [esp + 0x7c], eax
            //   56                   | movsd               qword ptr [esp + 0x70], xmm0
            //   56                   | mov                 ecx, dword ptr [edx + 0x48]

        $sequence_43 = { 55 89e5 648b0d18000000 8b4130 83b8a400000006 }
            // n = 5, score = 500
            //   55                   | mov                 dword ptr [esi + 0x34], ebx
            //   89e5                 | mov                 dword ptr [esp], eax
            //   648b0d18000000       | mov                 eax, dword ptr [esp + 0x50]
            //   8b4130               | mov                 dword ptr [esp + 0x14], ecx
            //   83b8a400000006       | mov                 ecx, dword ptr [esp + 0x18]

        $sequence_44 = { 8b5508 befbffffff c600e9 29d6 01ce 897001 }
            // n = 6, score = 500
            //   8b5508               | and                 ebx, 0xfffffff0
            //   befbffffff           | lea                 ebx, [eax + 1]
            //   c600e9               | test                bl, 0xf
            //   29d6                 | je                  0xb
            //   01ce                 | and                 ebx, 0xfffffff0
            //   897001               | add                 ebx, 0x10

        $sequence_45 = { 50 51 52 01c8 01d0 }
            // n = 5, score = 500
            //   50                   | mov                 ebx, 0x844cc300
            //   51                   | push                edi
            //   52                   | xor                 edi, edi
            //   01c8                 | push                ebx
            //   01d0                 | push                esi

        $sequence_46 = { 8b7d08 83fe00 8945f0 894dec }
            // n = 4, score = 500
            //   8b7d08               | push                esi
            //   83fe00               | push                eax
            //   8945f0               | mov                 eax, dword ptr [edi + 0x74]
            //   894dec               | add                 eax, dword ptr [edi + 0x8c]

        $sequence_47 = { 89d6 83c60c 8b7df4 8b4c0f0c }
            // n = 4, score = 500
            //   89d6                 | imul                edx, edx, 0x1003f
            //   83c60c               | add                 eax, 0x20
            //   8b7df4               | jmp                 8
            //   8b4c0f0c             | movzx               eax, ax

        $sequence_48 = { 8bec 83ec08 56 57 8bf1 33ff }
            // n = 6, score = 500
            //   8bec                 | push                0
            //   83ec08               | push                1
            //   56                   | push                0
            //   57                   | push                esi
            //   8bf1                 | mov                 edi, eax
            //   33ff                 | test                edi, edi

        $sequence_49 = { 51 8d4df8 51 ff75f8 50 6a03 6a30 }
            // n = 7, score = 500
            //   51                   | push                -1
            //   8d4df8               | push                eax
            //   51                   | push                ecx
            //   ff75f8               | push                eax
            //   50                   | push                0
            //   6a03                 | push                1
            //   6a30                 | push                0

        $sequence_50 = { 8b466c 5f 5e 5b 8be5 5d }
            // n = 6, score = 500
            //   8b466c               | cmp                 eax, 0x7f
            //   5f                   | push                0
            //   5e                   | push                -1
            //   5b                   | push                eax
            //   8be5                 | push                ecx
            //   5d                   | push                eax

        $sequence_51 = { 8b5d08 b8afa96e5e 56 57 00b807000000 008b45fc33d2 00b871800780 }
            // n = 7, score = 500
            //   8b5d08               | mov                 edx, dword ptr [edi]
            //   b8afa96e5e           | add                 esp, 0xc
            //   56                   | mov                 ecx, dword ptr [ebp + 0xc]
            //   57                   | mov                 eax, edx
            //   00b807000000         | or                  eax, ecx
            //   008b45fc33d2         | cmp                 eax, -1
            //   00b871800780         | test                eax, eax

        $sequence_52 = { 8bf1 bb00c34c84 57 33ff }
            // n = 4, score = 500
            //   8bf1                 | mov                 edx, esp
            //   bb00c34c84           | xor                 esi, esi
            //   57                   | mov                 dword ptr [edx + 0xc], esi
            //   33ff                 | mov                 dword ptr [edx + 8], esi

        $sequence_53 = { 83ec10 53 6a00 8d45fc }
            // n = 4, score = 500
            //   83ec10               | mov                 dword ptr [esp + 4], ecx
            //   53                   | mov                 ecx, dword ptr [esp + 0x1c]
            //   6a00                 | cmove               ecx, eax
            //   8d45fc               | sub                 edx, dword ptr [ecx + 0x34]

        $sequence_54 = { 6a03 6a00 6a00 ff7508 53 50 }
            // n = 6, score = 500
            //   6a03                 | xor                 esi, esi
            //   6a00                 | mov                 dword ptr [edx + 0xc], esi
            //   6a00                 | mov                 dword ptr [edx + 8], esi
            //   ff7508               | xor                 ecx, ecx
            //   53                   | mov                 edx, esp
            //   50                   | xor                 esi, esi

        $sequence_55 = { 8b7020 8b7840 89c3 83c33c }
            // n = 4, score = 300
            //   8b7020               | shr                 eax, 7
            //   8b7840               | shr                 eax, 7
            //   89c3                 | inc                 ebx
            //   83c33c               | cmp                 eax, 0x7f

        $sequence_56 = { c605????????00 0fb6d8 e8???????? 0fb6c3 }
            // n = 4, score = 200
            //   c605????????00       |                     
            //   0fb6d8               | add                 ecx, edx
            //   e8????????           |                     
            //   0fb6c3               | shr                 ecx, 6

        $sequence_57 = { e8???????? 84c0 7519 33c9 }
            // n = 4, score = 200
            //   e8????????           |                     
            //   84c0                 | shl                 eax, cl
            //   7519                 | sub                 ecx, edx
            //   33c9                 | shr                 ecx, 1

        $sequence_58 = { ff15???????? 83f803 7405 83f802 751e }
            // n = 5, score = 200
            //   ff15????????         |                     
            //   83f803               | inc                 ecx
            //   7405                 | mov                 ecx, ebx
            //   83f802               | shl                 eax, cl
            //   751e                 | add                 edx, eax

        $sequence_59 = { 7519 33c9 0f1f4000 0fb6840c30010000 }
            // n = 4, score = 200
            //   7519                 | inc                 ecx
            //   33c9                 | mov                 byte ptr [eax - 3], al
            //   0f1f4000             | inc                 ecx
            //   0fb6840c30010000     | mov                 byte ptr [eax - 2], cl

        $sequence_60 = { 743e 8b5c2430 85db 741d }
            // n = 4, score = 200
            //   743e                 | mov                 dword ptr [ebp + 0x20], ecx
            //   8b5c2430             | inc                 ecx
            //   85db                 | mov                 edx, eax
            //   741d                 | shl                 edx, cl

        $sequence_61 = { 8bf8 e8???????? eb04 8b7c2430 }
            // n = 4, score = 200
            //   8bf8                 | shl                 edx, cl
            //   e8????????           |                     
            //   eb04                 | inc                 ecx
            //   8b7c2430             | mov                 ecx, ebx

        $sequence_62 = { 31c9 89e2 31f6 89720c 897208 }
            // n = 5, score = 200
            //   31c9                 | ja                  0
            //   89e2                 | shr                 eax, 7
            //   31f6                 | inc                 edi
            //   89720c               | cmp                 eax, 0x7f
            //   897208               | ja                  0

        $sequence_63 = { 488d15e70f0000 e8???????? 84c0 0f84f1000000 48899c2480030000 }
            // n = 5, score = 100
            //   488d15e70f0000       | inc                 ecx
            //   e8????????           |                     
            //   84c0                 | mov                 byte ptr [eax - 2], cl
            //   0f84f1000000         | shr                 cx, 8
            //   48899c2480030000     | inc                 ecx

        $sequence_64 = { 84c0 7466 0f1f4000 488b9c2448040000 4885db }
            // n = 5, score = 100
            //   84c0                 | cmp                 ebx, ecx
            //   7466                 | dec                 ebp
            //   0f1f4000             | lea                 eax, [eax + 4]
            //   488b9c2448040000     | inc                 ecx
            //   4885db               | mov                 byte ptr [eax - 3], al

        $sequence_65 = { 8b4a48 894e20 83c418 5e c3 }
            // n = 5, score = 100
            //   8b4a48               | setne               al
            //   894e20               | pop                 ebx
            //   83c418               | mov                 esp, ebp
            //   5e                   | add                 eax, 0x20
            //   c3                   | jmp                 5

        $sequence_66 = { 8b4c241c 0f44c8 2b5134 8b442420 890424 89542404 894c2418 }
            // n = 7, score = 100
            //   8b4c241c             | inc                 ecx
            //   0f44c8               | cmp                 eax, 0x7f
            //   2b5134               | ja                  5
            //   8b442420             | jbe                 0xb
            //   890424               | shr                 eax, 7
            //   89542404             | inc                 ecx
            //   894c2418             | cmp                 eax, 0x7f

        $sequence_67 = { 897204 8932 8b15???????? 8944247c f20f11442470 }
            // n = 5, score = 100
            //   897204               | mov                 esp, ebp
            //   8932                 | cmp                 dword ptr [ebx], eax
            //   8b15????????         |                     
            //   8944247c             | pop                 edi
            //   f20f11442470         | pop                 esi

        $sequence_68 = { 813c3850450000 0f44f5 895e34 890424 }
            // n = 4, score = 100
            //   813c3850450000       | push                1
            //   0f44f5               | push                0
            //   895e34               | push                esi
            //   890424               | mov                 edi, eax

        $sequence_69 = { e8???????? 8d0d2231d800 890424 894c2404 e8???????? 8b4c242c 894130 }
            // n = 7, score = 100
            //   e8????????           |                     
            //   8d0d2231d800         | inc                 ecx
            //   890424               | mov                 ecx, 1
            //   894c2404             | cmp                 eax, 0x7f
            //   e8????????           |                     
            //   8b4c242c             | jbe                 0xe
            //   894130               | shr                 eax, 7

        $sequence_70 = { 8bf8 85ff 7443 be???????? e8???????? }
            // n = 5, score = 100
            //   8bf8                 | movzx               eax, cx
            //   85ff                 | shr                 ecx, 0x10
            //   7443                 | shr                 ax, 8
            //   be????????           |                     
            //   e8????????           |                     

        $sequence_71 = { 8b442450 894c2414 8b4c2418 8908 }
            // n = 4, score = 100
            //   8b442450             | test                edi, edi
            //   894c2414             | je                  0x41
            //   8b4c2418             | push                ebx
            //   8908                 | xor                 eax, eax

        $sequence_72 = { 8b5010 51 52 c745f48072e601 e8???????? 8bd8 85db }
            // n = 7, score = 100
            //   8b5010               | mov                 byte ptr [eax], cl
            //   51                   | movzx               eax, cx
            //   52                   | shr                 ecx, 0x10
            //   c745f48072e601       | shr                 ax, 8
            //   e8????????           |                     
            //   8bd8                 | inc                 ecx
            //   85db                 | mov                 byte ptr [eax], cl

    condition:
        7 of them and filesize < 733184
}